@@ -1,7 +1,7 @@
 /*
  * Global program option structure and the parsing function prototype.
  *
- * Copyright 2005 Andrew Wood, distributed under the Artistic License.
+ * Copyright 2007 Andrew Wood, distributed under the Artistic License 2.0.
  */
 
 #ifndef _OPTIONS_H
@@ -26,9 +26,11 @@ struct opts_s {           /* structure describing run-time options */
 	unsigned char cursor;          /* whether to use cursor positioning */
 	unsigned char numeric;         /* numeric output only */
 	unsigned char wait;            /* wait for transfer before display */
+	unsigned char linemode;        /* count lines instead of bytes */
 	unsigned char no_op;           /* do nothing other than pipe data */
 	unsigned long long rate_limit; /* rate limit, in bytes per second */
 	unsigned long long buffer_size;/* buffer size, in bytes (0=default) */
+	unsigned int remote;           /* PID of pv to update settings of */
 	unsigned long long size;       /* total size of data */
 	double interval;               /* interval between updates */
 	unsigned int width;            /* screen width */
