@@ -1,7 +1,7 @@
 /*
  * Output command-line help to stdout.
  *
- * Copyright 2005 Andrew Wood, distributed under the Artistic License.
+ * Copyright 2007 Andrew Wood, distributed under the Artistic License 2.0.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -49,6 +49,8 @@ void display_help(void)
 		 _("display nothing until first byte transferred")},
 		{"-s", "--size", _("SIZE"),
 		 _("set estimated data size to SIZE bytes")},
+		{"-l", "--line-mode", 0,
+		 _("count lines instead of bytes")},
 		{"-i", "--interval", _("SEC"),
 		 _("update every SEC seconds")},
 		{"-w", "--width", _("WIDTH"),
@@ -62,11 +64,11 @@ void display_help(void)
 		 _("limit transfer to RATE bytes per second")},
 		{"-B", "--buffer-size", _("BYTES"),
 		 _("use a buffer size of BYTES")},
+		{"-R", "--remote", _("PID"),
+		 _("update settings of process PID")},
 		{"", 0, 0, 0},
 		{"-h", "--help", 0,
 		 _("show this help and exit")},
-		{"-l", "--license", 0,
-		 _("show the license this program is distributed under")},
 		{"-V", "--version", 0,
 		 _("show version information and exit")},
 		{0, 0, 0, 0}
