@@ -1,7 +1,7 @@
 /*
  * Parse command-line options.
  *
- * Copyright 2005 Andrew Wood, distributed under the Artistic License.
+ * Copyright 2007 Andrew Wood, distributed under the Artistic License 2.0.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -9,6 +9,7 @@
 #endif
 #include "options.h"
 #include "library/getopt.h"
+#include "pv.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -18,11 +19,7 @@
 
 
 void display_help(void);
-void display_license(void);
 void display_version(void);
-long long getnum_ll(char *);
-double getnum_d(char *);
-int getnum_i(char *);
 
 
 /*
@@ -53,7 +50,6 @@ opts_t opts_parse(int argc, char **argv)
 #ifdef HAVE_GETOPT_LONG
 	struct option long_options[] = {
 		{"help", 0, 0, 'h'},
-		{"license", 0, 0, 'l'},
 		{"version", 0, 0, 'V'},
 		{"progress", 0, 0, 'p'},
 		{"timer", 0, 0, 't'},
@@ -66,17 +62,19 @@ opts_t opts_parse(int argc, char **argv)
 		{"cursor", 0, 0, 'c'},
 		{"wait", 0, 0, 'W'},
 		{"size", 1, 0, 's'},
+		{"line-mode", 0, 0, 'l'},
 		{"interval", 1, 0, 'i'},
 		{"width", 1, 0, 'w'},
 		{"height", 1, 0, 'H'},
 		{"name", 1, 0, 'N'},
 		{"rate-limit", 1, 0, 'L'},
 		{"buffer-size", 1, 0, 'B'},
+		{"remote", 1, 0, 'R'},
 		{0, 0, 0, 0}
 	};
 	int option_index = 0;
 #endif
-	char *short_options = "hlVpterbfnqcWs:i:w:H:N:L:B:";
+	char *short_options = "hVpterbfnqcWs:li:w:H:N:L:B:R:";
 	int c, numopts;
 	opts_t opts;
 
@@ -124,11 +122,6 @@ opts_t opts_parse(int argc, char **argv)
 			opts->do_nothing = 1;
 			return opts;
 			break;
-		case 'l':
-			display_license();
-			opts->do_nothing = 1;
-			return opts;
-			break;
 		case 'V':
 			display_version();
 			opts->do_nothing = 1;
@@ -172,25 +165,31 @@ opts_t opts_parse(int argc, char **argv)
 			opts->wait = 1;
 			break;
 		case 's':
-			opts->size = getnum_ll(optarg);
+			opts->size = pv_getnum_ll(optarg);
+			break;
+		case 'l':
+			opts->linemode = 1;
 			break;
 		case 'i':
-			opts->interval = getnum_d(optarg);
+			opts->interval = pv_getnum_d(optarg);
 			break;
 		case 'w':
-			opts->width = getnum_i(optarg);
+			opts->width = pv_getnum_i(optarg);
 			break;
 		case 'H':
-			opts->height = getnum_i(optarg);
+			opts->height = pv_getnum_i(optarg);
 			break;
 		case 'N':
 			opts->name = optarg;
 			break;
 		case 'L':
-			opts->rate_limit = getnum_ll(optarg);
+			opts->rate_limit = pv_getnum_ll(optarg);
 			break;
 		case 'B':
-			opts->buffer_size = getnum_ll(optarg);
+			opts->buffer_size = pv_getnum_ll(optarg);
+			break;
+		case 'R':
+			opts->remote = pv_getnum_i(optarg);
 			break;
 		default:
 #ifdef HAVE_GETOPT_LONG
@@ -221,14 +220,6 @@ opts_t opts_parse(int argc, char **argv)
 		opts->bytes = 1;
 	}
 
-	/*
-	 * Interval must be at least 0.1 second, and at most 10 minutes.
-	 */
-	if (opts->interval < 0.1)
-		opts->interval = 0.1;
-	if (opts->interval > 600)
-		opts->interval = 600;
-
 	/*
 	 * Store remaining command-line arguments.
 	 */
