@@ -1,7 +1,7 @@
 /*
  * Output version information to stdout.
  *
- * Copyright 2005 Andrew Wood, distributed under the Artistic License.
+ * Copyright 2007 Andrew Wood, distributed under the Artistic License 2.0.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -24,7 +24,7 @@ void display_version(void)
 	printf("\n\n");
 	printf("%s",
 	       _("This program is free software, and is being distributed "
-		 "under the\nterms of the Artistic License."));
+		 "under the\nterms of the Artistic License 2.0."));
 	printf("\n\n");
 	printf("%s",
 	       _
@@ -32,18 +32,6 @@ void display_version(void)
 		"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
 		"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."));
 	printf("\n\n");
-#ifdef HAVE_GETOPT_LONG
-	printf(				    /* RATS: ignore */
-		      _
-		      ("For more information, please run `%s --license'."),
-		      PROGRAM_NAME);
-#else
-	printf(				    /* RATS: ignore */
-		      _
-		      ("For more information, please run `%s -l'."),
-		      PROGRAM_NAME);
-#endif
-	printf("\n");
 }
 
 /* EOF */
